Package: DeepTarget
Type: Package
Title: Deep characterization of cancer drugs
Version: 1.4.0
Authors@R: c(
    person("Sanju", "Sinha", email = "sanju@terpmail.umd.edu", role ="aut"),
    person("Trinh", "Nguyen", email = "tinh.nguyen@nih.gov", role = c("aut","cre"),comment=c(ORCID="0000-0002-6606-6948")),
    person("Ying", "Hu", email = "yhu@mail.nih.gov", role ="aut"))
Description: This package predicts a drug’s primary target(s) or secondary target(s) by integrating large-scale genetic and drug screens from the Cancer Dependency Map project run by the Broad Institute. It further investigates whether the drug specifically targets the wild-type or mutated target forms. To show how to use this package in practice, we provided sample data along with step-by-step example.
License: GPL-2
Encoding: UTF-8
biocViews: GeneTarget, GenePrediction,Pathways, GeneExpression, RNASeq,
        ImmunoOncology,DifferentialExpression, GeneSetEnrichment,
        ReportWriting,CRISPR
RoxygenNote: 7.2.3
VignetteBuilder: knitr
Suggests: BiocStyle, knitr, rmarkdown
Imports: fgsea, ggplot2, stringr, ggpubr, BiocParallel, pROC, stats,
        grDevices, graphics, depmap, readr, dplyr
Depends: R (>= 4.2.0)
git_url: https://git.bioconductor.org/packages/DeepTarget
git_branch: RELEASE_3_22
git_last_commit: 5b8241e
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 03:31:21 UTC; biocbuild
Author: Sanju Sinha [aut],
  Trinh Nguyen [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-6606-6948>),
  Ying Hu [aut]
Maintainer: Trinh Nguyen <tinh.nguyen@nih.gov>
